@@ -36,6 +36,8 @@ class ParamDef(object):
 	AGENT_STAT = 35
 	JVM_THREAD_DUMP = 37
 	JVM_HEAP_DUMP = 38
+	KUBENETES = 39
+	GET_ACTIVE_STATS = 40
 	MODULE_DEPENDENCY = 101
 	DBX_INFO = 201
 	DBX_SETTINGS = 202
