@@ -157,6 +157,9 @@ class UdpSession(object):
             datas.append(data)
 
             cls.send_packet(PacketTypeEnum.ACTIVE_STACK, None, datas)
+            stats = TraceContextManager.getActiveStats()
+            datas = [','.join([str(x) for x in stats])]
+            cls.send_packet(PacketTypeEnum.ACTIVE_STATS, None, datas)
         else:
             # param pack
             # format: "[packetType], [ctx], [datas: xxxx xxxx xxxx]"
