@@ -79,9 +79,11 @@ def intercept_publish(fn, *args, **kwargs):
 
     ctx.active_dbc = 0
     ctx.db_opening = True
-    datas = [text]
     ctx.elapsed = DateUtil.nowSystem() - start_time
-    UdpSession.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
+
+    datas = [' ', ' ', 'MQ SESSION INFO: ' + text]
+    UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+
 
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
