@@ -15,12 +15,30 @@ import re
 
 from whatap.util.hexa32 import Hexa32
 
+import traceback, threading
+
+def isEventlet():
+    greenlet = sys.modules.get('greenlet')
+
+    if greenlet:
+        current = greenlet.getcurrent()
+        if current is not None and current.parent:
+            print('thread:',threading.get_ident(),'greenlet:', id(current.parent))
+            traceback.print_stack()
+            return True
+    else:
+        return False
 
 def trace_handler(fn, start=False):
     def handler(func):
         @wraps(func)
         def wrapper(*args, **kwargs):
+            # if isEventlet():
+            #     print("trace_handler: greenlet found")
+            # else:
+            #     print("trace_handler: greenlet not found")
             ctx = TraceContextManager.getLocalContext()
+            # print("trace_handler ctx:", ctx)
             if not start and not ctx:
                 return fn(*args, **kwargs)
             
@@ -60,7 +78,7 @@ def start_interceptor(ctx):
              ctx.userid,
              ctx.isStaticContents
              ]
-    
+    # print("start_interceptor txid:", ctx.id)
     UdpSession.send_packet(PacketTypeEnum.TX_START, ctx, datas)
     
     return ctx
@@ -69,7 +87,7 @@ def start_interceptor(ctx):
 def end_interceptor(thread_id=None):
     ctx = TraceContextManager.getContext(
         thread_id) if thread_id else TraceContextManager.getLocalContext()
-    
+    # print("end_interceptor txid:", ctx.id)
     if conf.dev:
         logging.debug('end   transaction id(seq): {}'.format(ctx.id),
                       extra={'id': 'WA112'})
@@ -92,7 +110,6 @@ def interceptor(rn_environ, *args, **kwargs):
     fn, environ = rn_environ
     
     ctx = TraceContext()
-    
     ctx.host = environ.get('HTTP_HOST', '').split(':')[0]
     ctx.service_name = environ.get('PATH_INFO', '')
 
@@ -127,7 +144,6 @@ def interceptor(rn_environ, *args, **kwargs):
     
     callback = fn(*args, **kwargs)
 
-    ctx = TraceContextManager.getLocalContext()
     if ctx:
         query_string = environ.get('QUERY_STRING', '')
         if query_string:
@@ -326,8 +342,9 @@ def addQuote(arg_dict):
     return quoted_dict
 
 def interceptor_db_execute(fn, *args, **kwargs):
+    # print('interceptor_db_execute step -1')
     ctx = TraceContextManager.getLocalContext()
-
+    # print('interceptor_db_execute step -2 ctx:', ctx)
     self = args[0]
     query = None
     if len(args) > 2 and type(args[2]) == dict and args[2]:
@@ -340,26 +357,33 @@ def interceptor_db_execute(fn, *args, **kwargs):
             query = args[1].decode()
     except Exception as e:
         query = args[1]
-
+    #print('interceptor_db_execute step -3', query)
     if not query or ctx.active_sqlhash:
+        #print('interceptor_db_execute step -3.1', ctx.active_sqlhash)
         return fn(*args, **kwargs)
-    
+
+
+    # print('interceptor_db_execute step -4')
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
     ctx.active_sqlhash = query
-    
+    # print('interceptor_db_execute step -5')
     try:
         callback = fn(*args, **kwargs)
+        # print('interceptor_db_execute step -6')
         return callback
     except Exception as e:
+
         interceptor_step_error(e)
     finally:
+        # print('interceptor_db_execute step -7 txid:', ctx.id)
         datas = [ctx.lctx.get('dbc', ''), query]
         ctx.elapsed = DateUtil.nowSystem() - start_time
         UdpSession.send_packet(PacketTypeEnum.TX_SQL, ctx,
                                datas)
-        
+        # print('interceptor_db_execute step -8')
         count = self.rowcount
+        # print('interceptor_db_execute step -9', count)
         if count > -1:
             desc = '{0}: {1}'.format('Fetch count', count)
             datas = [' ', ' ', desc]
@@ -367,7 +391,7 @@ def interceptor_db_execute(fn, *args, **kwargs):
             UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
         
         ctx.active_sqlhash = 0
-
+        # print('interceptor_db_execute step -10')
 
 def interceptor_db_close(fn, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
