@@ -35,7 +35,7 @@ DEFINITION = {
     ],
     'database_toolkit': [
         ('sqlalchemy.orm.session', 'instrument_sqlalchemy'),
-        ('sqlalchemy.engine.default', 'instrument_sqlalchemy_engine'),
+        # ('sqlalchemy.engine.default', 'instrument_sqlalchemy_engine'),
     ],
     'application_wsgi': [
         ('', ''),
@@ -84,7 +84,11 @@ DEFINITION = {
     'amqp_kombu':[
         ('kombu','instrument_kombu'),
     ],
-    # 'amqp_pika':[
-    #     ('pika.channel','instrument_pika'),
-    # ],
+    'amqp_pika':[
+        ('pika.channel','instrument_pika'),
+    ],
+    'application_nameko': [
+        ('nameko.containers', 'instrument_nameko_spawn_worker'),
+    ],
+
 }
